@@ -1,8 +1,9 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
  * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
  * Copyright (c) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
- *  
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -20,7 +21,7 @@
  * For further information visit http://libwpd.sourceforge.net
  */
 
-/* "This product is not manufactured, approved, or supported by 
+/* "This product is not manufactured, approved, or supported by
  * Corel Corporation or Corel Corporation Limited."
  */
 
@@ -31,22 +32,26 @@
 
 class WP1FixedLengthGroup : public WP1Part
 {
- public:
+public:
 	WP1FixedLengthGroup(uint8_t group); // WP1FixedLengthGroup should _never_ be constructed, only its inherited classes
 	virtual ~WP1FixedLengthGroup() {}
-	
-	static WP1FixedLengthGroup * constructFixedLengthGroup(WPXInputStream *input, WPXEncryption *encryption, uint8_t group);
+
+	static WP1FixedLengthGroup *constructFixedLengthGroup(WPXInputStream *input, WPXEncryption *encryption, uint8_t group);
 
 	static bool isGroupConsistent(WPXInputStream *input, WPXEncryption *encryption, const uint8_t groupID);
 
- protected:
+protected:
 	void _read(WPXInputStream *input, WPXEncryption *encryption);
- 	virtual void _readContents(WPXInputStream * /* input */, WPXEncryption * /* encryption */) {};
+	virtual void _readContents(WPXInputStream * /* input */, WPXEncryption * /* encryption */) {};
 
-	uint8_t getGroup() const { return m_group; }
+	uint8_t getGroup() const
+	{
+		return m_group;
+	}
 
- private:
+private:
 	uint8_t m_group;
 };
 
 #endif /* WP1FIXEDLENGTHGROUP_H */
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
