@@ -1,6 +1,7 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
  * Copyright (C) 2004 Marc Maurer (uwog@uwog.net)
- *  
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
@@ -18,7 +19,7 @@
  * For further information visit http://libwpd.sourceforge.net
  */
 
-/* "This product is not manufactured, approved, or supported by 
+/* "This product is not manufactured, approved, or supported by
  * Corel Corporation or Corel Corporation Limited."
  */
 
@@ -31,8 +32,9 @@
 class WP3EndOfLinePageGroup : public WP3VariableLengthGroup
 {
 public:
-	WP3EndOfLinePageGroup(WPXInputStream *input);	
+	WP3EndOfLinePageGroup(WPXInputStream *input, WPXEncryption *encryption);
 	void parse(WP3Listener *listener);
 };
 
 #endif /* WP3ENDOFLINEPAGEGROUP_H */
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
