@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
  * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
@@ -46,18 +47,33 @@ public:
 	WP42ContentListener(std::list<WPXPageSpan> &pageList, std::vector<WP42SubDocument *> &subDocuments, WPXDocumentInterface *documentInterface);
 	~WP42ContentListener();
 
-	void startDocument() { WPXContentListener::startDocument(); }
-	void startSubDocument() { WPXContentListener::startSubDocument(); }
-	void insertCharacter(uint16_t character);
+	void startDocument()
+	{
+		WPXContentListener::startDocument();
+	}
+	void startSubDocument()
+	{
+		WPXContentListener::startSubDocument();
+	}
+	void insertCharacter(uint32_t character);
 	void insertTab(uint8_t tabType, double tabPosition);
-	void insertBreak(uint8_t breakType) { WPXContentListener::insertBreak(breakType); }
+	void insertBreak(uint8_t breakType)
+	{
+		WPXContentListener::insertBreak(breakType);
+	}
 	void insertEOL();
 	void attributeChange(bool isOn, uint8_t attribute);
 	void marginReset(uint8_t leftMargin, uint8_t rightMargin);
 	void headerFooterGroup(uint8_t headerFooterDefinition, WP42SubDocument *subDocument);
 	void suppressPageCharacteristics(uint8_t /* suppressCode */) {}
-	void endDocument() { WPXContentListener::endDocument(); };
-	void endSubDocument() { WPXContentListener::endSubDocument(); };
+	void endDocument()
+	{
+		WPXContentListener::endDocument();
+	};
+	void endSubDocument()
+	{
+		WPXContentListener::endSubDocument();
+	};
 
 protected:
 	void _handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType, WPXTableList tableList, int nextTableIndice = 0);
@@ -66,10 +82,11 @@ protected:
 	void _changeList() {};
 
 private:
-	WP42ContentListener(const WP42ContentListener&);
-	WP42ContentListener& operator=(const WP42ContentListener&);
+	WP42ContentListener(const WP42ContentListener &);
+	WP42ContentListener &operator=(const WP42ContentListener &);
 	WP42ContentParsingState *m_parseState;
 	std::vector<WP42SubDocument *> &m_subDocuments;
 };
 
 #endif /* WP42LISTENER_H */
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
