@@ -1,6 +1,7 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
  * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
- *  
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -18,7 +19,7 @@
  * For further information visit http://libwpd.sourceforge.net
  */
 
-/* "This product is not manufactured, approved, or supported by 
+/* "This product is not manufactured, approved, or supported by
  * Corel Corporation or Corel Corporation Limited."
  */
 
@@ -31,16 +32,17 @@
 class WP42HeaderFooterGroup : public WP42MultiByteFunctionGroup
 {
 public:
-	WP42HeaderFooterGroup(WPXInputStream *input, uint8_t group);
-	~WP42HeaderFooterGroup();	
-	void _readContents(WPXInputStream *input);
+	WP42HeaderFooterGroup(WPXInputStream *input, WPXEncryption *encryption, uint8_t group);
+	~WP42HeaderFooterGroup();
+	void _readContents(WPXInputStream *input, WPXEncryption *encryption);
 	void parse(WP42Listener *listener);
 
 private:
-	WP42HeaderFooterGroup(const WP42HeaderFooterGroup&);
-	WP42HeaderFooterGroup& operator=(const WP42HeaderFooterGroup&);
+	WP42HeaderFooterGroup(const WP42HeaderFooterGroup &);
+	WP42HeaderFooterGroup &operator=(const WP42HeaderFooterGroup &);
 	uint8_t m_definition;
 	WP42SubDocument *m_subDocument;
 };
 
 #endif /* WP42HEADERFOOTERGROUP_H */
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
