@@ -1,6 +1,7 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
  * Copyright (C) 2005 Fridrich Strba (fridrich.strba@bluewin.ch)
- *  
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
@@ -18,7 +19,7 @@
  * For further information visit http://libwpd.sourceforge.net
  */
 
-/* "This product is not manufactured, approved, or supported by 
+/* "This product is not manufactured, approved, or supported by
  * Corel Corporation or Corel Corporation Limited."
  */
 #include <string.h>
@@ -27,27 +28,27 @@
 #include "WP5Parser.h"
 #include "libwpd_internal.h"
 
-WP5FontNameStringPoolPacket::WP5FontNameStringPoolPacket(WPXInputStream *input, int /* id */, uint32_t dataOffset, uint32_t dataSize) :
-	WP5GeneralPacketData(input),
+WP5FontNameStringPoolPacket::WP5FontNameStringPoolPacket(WPXInputStream *input, WPXEncryption *encryption, int /* id */, uint32_t dataOffset, uint32_t dataSize) :
+	WP5GeneralPacketData(),
 	m_fontNameString()
-{	
-	_read(input, dataOffset, dataSize);
+{
+	_read(input, encryption, dataOffset, dataSize);
 }
 
 WP5FontNameStringPoolPacket::~WP5FontNameStringPoolPacket()
 {
 }
 
-void WP5FontNameStringPoolPacket::_readContents(WPXInputStream *input, uint32_t dataSize)
+void WP5FontNameStringPoolPacket::_readContents(WPXInputStream *input, WPXEncryption *encryption, uint32_t dataSize)
 {
 	unsigned int tmpInitialOffset = input->tell();
 	while ((long)input->tell() < (long)(tmpInitialOffset + dataSize))
 	{
 		unsigned int offset = input->tell() - tmpInitialOffset;
-		WPXString fontName = readCString(input);
+		WPXString fontName = readCString(input, encryption);
 		m_fontNameString[offset] = fontName;
 	}
-	
+
 	for (std::map<unsigned int, WPXString>::const_iterator Iter = m_fontNameString.begin(); Iter != m_fontNameString.end(); Iter++)
 		WPD_DEBUG_MSG(("WP5 Font Name String Pool Packet: offset: %i font name: %s\n", Iter->first, (Iter->second).cstr()));
 }
@@ -61,3 +62,4 @@ WPXString WP5FontNameStringPoolPacket::getFontName(const unsigned int offset) co
 	return WPXString("Times New Roman");
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
