@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
  * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
@@ -38,35 +39,35 @@ WP6FixedLengthGroup::WP6FixedLengthGroup(uint8_t groupID)
 {
 }
 
-WP6FixedLengthGroup * WP6FixedLengthGroup::constructFixedLengthGroup(WPXInputStream *input, uint8_t groupID)
+WP6FixedLengthGroup *WP6FixedLengthGroup::constructFixedLengthGroup(WPXInputStream *input, WPXEncryption *encryption, uint8_t groupID)
 {
 	switch (groupID)
 	{
-		case WP6_TOP_EXTENDED_CHARACTER:
-			return new WP6ExtendedCharacterGroup(input, groupID);
+	case WP6_TOP_EXTENDED_CHARACTER:
+		return new WP6ExtendedCharacterGroup(input, encryption, groupID);
 
-		case WP6_TOP_UNDO_GROUP:
-			return new WP6UndoGroup(input, groupID);
+	case WP6_TOP_UNDO_GROUP:
+		return new WP6UndoGroup(input, encryption, groupID);
 
-		case WP6_TOP_ATTRIBUTE_ON:
-			return new WP6AttributeOnGroup(input, groupID);
+	case WP6_TOP_ATTRIBUTE_ON:
+		return new WP6AttributeOnGroup(input, encryption, groupID);
 
-		case WP6_TOP_ATTRIBUTE_OFF:
-			return new WP6AttributeOffGroup(input, groupID);
+	case WP6_TOP_ATTRIBUTE_OFF:
+		return new WP6AttributeOffGroup(input, encryption, groupID);
 
-		case WP6_TOP_HIGHLIGHT_ON:
-			return new WP6HighlightOnGroup(input, groupID);
+	case WP6_TOP_HIGHLIGHT_ON:
+		return new WP6HighlightOnGroup(input, encryption, groupID);
 
-		case WP6_TOP_HIGHLIGHT_OFF:
-			return new WP6HighlightOffGroup(input, groupID);
+	case WP6_TOP_HIGHLIGHT_OFF:
+		return new WP6HighlightOffGroup(input, encryption, groupID);
 
 		// Add the remaining cases here
-		default:
-			return new WP6UnsupportedFixedLengthGroup(input, groupID);
+	default:
+		return new WP6UnsupportedFixedLengthGroup(input, encryption, groupID);
 	}
 }
 
-bool WP6FixedLengthGroup::isGroupConsistent(WPXInputStream *input, const uint8_t groupID)
+bool WP6FixedLengthGroup::isGroupConsistent(WPXInputStream *input, WPXEncryption *encryption, const uint8_t groupID)
 {
 	if (groupID == (uint8_t)0xFF)
 		return false;
@@ -75,18 +76,18 @@ bool WP6FixedLengthGroup::isGroupConsistent(WPXInputStream *input, const uint8_t
 
 	try
 	{
-		int size = WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[groupID-0xF0];
-		if (input->seek((startPosition + size - 2 - (uint32_t)input->tell()), WPX_SEEK_CUR) || input->atEOS())
+		uint32_t size = WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[groupID-0xF0];
+		if (input->seek((startPosition + size - 2), WPX_SEEK_SET) || input->atEOS())
 		{
 			input->seek(startPosition, WPX_SEEK_SET);
 			return false;
 		}
-		if (groupID != readU8(input))
+		if (input->atEOS() || groupID != readU8(input, encryption))
 		{
 			input->seek(startPosition, WPX_SEEK_SET);
 			return false;
 		}
-		
+
 		input->seek(startPosition, WPX_SEEK_SET);
 		return true;
 	}
@@ -97,16 +98,16 @@ bool WP6FixedLengthGroup::isGroupConsistent(WPXInputStream *input, const uint8_t
 	}
 }
 
-void WP6FixedLengthGroup::_read(WPXInputStream *input)
+void WP6FixedLengthGroup::_read(WPXInputStream *input, WPXEncryption *encryption)
 {
 	uint32_t startPosition = input->tell();
-	_readContents(input);
+	_readContents(input, encryption);
 
 	if (m_group >= 0xF0 && m_group < 0xFF) // just an extra safety check
 	{
-		uint32_t size = WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[m_group-0xF0];
-		input->seek((startPosition + size - 2 - input->tell()), WPX_SEEK_CUR);
-		if (input->atEOS() || m_group != readU8(input))
+		int size = WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[m_group-0xF0];
+		input->seek((startPosition + size - 2), WPX_SEEK_SET);
+		if (m_group != readU8(input, encryption))
 		{
 			WPD_DEBUG_MSG(("WordPerfect: Possible corruption detected: bailing out!\n"));
 			throw FileException();
@@ -115,3 +116,4 @@ void WP6FixedLengthGroup::_read(WPXInputStream *input)
 	else
 		throw FileException();
 }
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
