@@ -1,5 +1,6 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
- * Copyright (C) 2002-2005 William Lachance (william.lachance@sympatico.ca)
+ * Copyright (C) 2002-2005 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2004 Net Integration Technologies (http://www.net-itech.com)
  * Copyright (C) 2002-2003 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2004-2006 Fridrich Strba (fridrich.strba@bluewin.ch)
@@ -28,11 +29,12 @@
 #include "WPXListener.h"
 
 WPXListener::WPXListener(std::list<WPXPageSpan> &pageList) :
-	m_isUndoOn(false),
-	m_pageList(pageList)
+	m_pageList(pageList),
+	m_isUndoOn(false)
 {
 }
 
 WPXListener::~WPXListener()
 {
 }
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
