@@ -1,8 +1,9 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
  * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2006-2007 Fridrich Strba (fridrich.strba@bluewin.ch)
- *  
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
@@ -20,7 +21,7 @@
  * For further information visit http://libwpd.sourceforge.net
  */
 
-/* "This product is not manufactured, approved, or supported by 
+/* "This product is not manufactured, approved, or supported by
  * Corel Corporation or Corel Corporation Limited."
  */
 
@@ -35,8 +36,8 @@ const double WPX_DEFAULT_PAGE_MARGIN_BOTTOM = 1.0;
 const uint8_t DUMMY_INTERNAL_HEADER_FOOTER = 16;
 
 // precondition: 0 <= headerFooterType <= 3 (i.e.: we don't handle watermarks here)
-WPXHeaderFooter::WPXHeaderFooter(const WPXHeaderFooterType headerFooterType, const WPXHeaderFooterOccurence occurence, 
-				 const uint8_t internalType, const WPXSubDocument * subDocument, WPXTableList tableList) :
+WPXHeaderFooter::WPXHeaderFooter(const WPXHeaderFooterType headerFooterType, const WPXHeaderFooterOccurence occurence,
+                                 const uint8_t internalType, const WPXSubDocument *subDocument, WPXTableList tableList) :
 	m_type(headerFooterType),
 	m_occurence(occurence),
 	m_internalType(internalType),
@@ -45,8 +46,8 @@ WPXHeaderFooter::WPXHeaderFooter(const WPXHeaderFooterType headerFooterType, con
 {
 }
 
-WPXHeaderFooter::WPXHeaderFooter(const WPXHeaderFooterType headerFooterType, const WPXHeaderFooterOccurence occurence, 
-				 const uint8_t internalType, const WPXSubDocument * subDocument) :
+WPXHeaderFooter::WPXHeaderFooter(const WPXHeaderFooterType headerFooterType, const WPXHeaderFooterOccurence occurence,
+                                 const uint8_t internalType, const WPXSubDocument *subDocument) :
 	m_type(headerFooterType),
 	m_occurence(occurence),
 	m_internalType(internalType),
@@ -64,7 +65,7 @@ WPXHeaderFooter::WPXHeaderFooter(const WPXHeaderFooter &headerFooter) :
 {
 }
 
-WPXHeaderFooter& WPXHeaderFooter::operator=(const WPXHeaderFooter &headerFooter)
+WPXHeaderFooter &WPXHeaderFooter::operator=(const WPXHeaderFooter &headerFooter)
 {
 	m_type = headerFooter.getType();
 	m_occurence = headerFooter.getOccurence();
@@ -120,7 +121,7 @@ WPXPageSpan::WPXPageSpan(const WPXPageSpan &page) :
 	m_pageSpan(page.getPageSpan())
 {
 	for (uint8_t i=0; i<WPX_NUM_HEADER_FOOTER_TYPES; i++)
-		m_isHeaderFooterSuppressed[i] = page.getHeaderFooterSuppression(i);	
+		m_isHeaderFooterSuppressed[i] = page.getHeaderFooterSuppression(i);
 }
 
 // NB: this is not a literal "clone" function: it is contingent on the side margins that are passed,
@@ -144,7 +145,7 @@ WPXPageSpan::WPXPageSpan(const WPXPageSpan &page, double paragraphMarginLeft, do
 	m_pageSpan(page.getPageSpan())
 {
 	for (int i=0; i<WPX_NUM_HEADER_FOOTER_TYPES; i++)
-		m_isHeaderFooterSuppressed[i] = false;	
+		m_isHeaderFooterSuppressed[i] = false;
 }
 
 WPXPageSpan::~WPXPageSpan()
@@ -152,22 +153,26 @@ WPXPageSpan::~WPXPageSpan()
 }
 
 
-void WPXPageSpan::setHeaderFooter(const WPXHeaderFooterType type, const uint8_t headerFooterType, const WPXHeaderFooterOccurence occurence, 
-				  const  WPXSubDocument * subDocument, WPXTableList tableList)
+void WPXPageSpan::setHeaderFooter(const WPXHeaderFooterType type, const uint8_t headerFooterType, const WPXHeaderFooterOccurence occurence,
+                                  const  WPXSubDocument *subDocument, WPXTableList tableList)
 {
 	WPXHeaderFooter headerFooter(type, occurence, headerFooterType, subDocument, tableList);
-	switch (occurence) 
+	switch (occurence)
 	{
 	case ALL:
 	case NEVER:
-		_removeHeaderFooter(type, ODD); _removeHeaderFooter(type, EVEN); _removeHeaderFooter(type, ALL);
+		_removeHeaderFooter(type, ODD);
+		_removeHeaderFooter(type, EVEN);
+		_removeHeaderFooter(type, ALL);
 		break;
 	case ODD:
-		_removeHeaderFooter(type, ODD); _removeHeaderFooter(type, ALL);
+		_removeHeaderFooter(type, ODD);
+		_removeHeaderFooter(type, ALL);
 		break;
 	case EVEN:
-		_removeHeaderFooter(type, EVEN); _removeHeaderFooter(type, ALL);
-		break;		
+		_removeHeaderFooter(type, EVEN);
+		_removeHeaderFooter(type, ALL);
+		break;
 	}
 
 	if ((occurence != NEVER) && (subDocument))
@@ -193,9 +198,10 @@ void WPXPageSpan::setHeaderFooter(const WPXHeaderFooterType type, const uint8_t
 
 void WPXPageSpan::_removeHeaderFooter(WPXHeaderFooterType type, WPXHeaderFooterOccurence occurence)
 {
-	for (std::vector<WPXHeaderFooter>::iterator iter = m_headerFooterList.begin(); iter != m_headerFooterList.end(); iter++) 
+	for (std::vector<WPXHeaderFooter>::iterator iter = m_headerFooterList.begin(); iter != m_headerFooterList.end(); iter++)
 	{
-		if ((*iter).getType() == type && (*iter).getOccurence() == occurence) {
+		if ((*iter).getType() == type && (*iter).getOccurence() == occurence)
+		{
 			WPD_DEBUG_MSG(("WordPerfect: Removing header/footer element of type: %i since it is identical to %i\n",(*iter).getType(), type));
 			m_headerFooterList.erase(iter);
 			return;
@@ -205,7 +211,7 @@ void WPXPageSpan::_removeHeaderFooter(WPXHeaderFooterType type, WPXHeaderFooterO
 
 bool WPXPageSpan::_containsHeaderFooter(WPXHeaderFooterType type, WPXHeaderFooterOccurence occurence)
 {
-	for (std::vector<WPXHeaderFooter>::iterator iter = m_headerFooterList.begin(); iter != m_headerFooterList.end(); iter++) 
+	for (std::vector<WPXHeaderFooter>::iterator iter = m_headerFooterList.begin(); iter != m_headerFooterList.end(); iter++)
 	{
 		if ((*iter).getType()==type && (*iter).getOccurence()==occurence)
 			return true;
@@ -216,36 +222,37 @@ bool WPXPageSpan::_containsHeaderFooter(WPXHeaderFooterType type, WPXHeaderFoote
 
 inline bool operator==(const WPXHeaderFooter &headerFooter1, const WPXHeaderFooter &headerFooter2)
 {
-	return ((headerFooter1.getType() == headerFooter2.getType()) && 
-		(headerFooter1.getSubDocument() == headerFooter2.getSubDocument()) &&
-		(headerFooter1.getOccurence() == headerFooter2.getOccurence()) &&
-		(headerFooter1.getInternalType() == headerFooter2.getInternalType()) );
+	return ((headerFooter1.getType() == headerFooter2.getType()) &&
+	        (headerFooter1.getSubDocument() == headerFooter2.getSubDocument()) &&
+	        (headerFooter1.getOccurence() == headerFooter2.getOccurence()) &&
+	        (headerFooter1.getInternalType() == headerFooter2.getInternalType()) );
 }
 
 bool operator==(const WPXPageSpan &page1, const WPXPageSpan &page2)
 {
 	if ((page1.getMarginLeft() != page2.getMarginLeft()) || (page1.getMarginRight() != page2.getMarginRight()) ||
-	    (page1.getMarginTop() != page2.getMarginTop())|| (page1.getMarginBottom() != page2.getMarginBottom()))
+	        (page1.getMarginTop() != page2.getMarginTop())|| (page1.getMarginBottom() != page2.getMarginBottom()))
 		return false;
 
-	if (page1.getPageNumberPosition() != page2.getPageNumberPosition()) 
+	if (page1.getPageNumberPosition() != page2.getPageNumberPosition())
 		return false;
 
 	if (page1.getPageNumberSuppression() != page2.getPageNumberSuppression())
 		return false;
-	
-	if (page1.getPageNumberOverriden() != page2.getPageNumberOverriden() || 
-		page1.getPageNumberOverride() != page2.getPageNumberOverride())
+
+	if (page1.getPageNumberOverriden() != page2.getPageNumberOverriden() ||
+	        page1.getPageNumberOverride() != page2.getPageNumberOverride())
 		return false;
 
 	if (page1.getPageNumberingType() != page2.getPageNumberingType())
 		return false;
 
 	if (page1.getPageNumberingFontName() != page2.getPageNumberingFontName() ||
-		page1.getPageNumberingFontSize() != page2.getPageNumberingFontSize())
+	        page1.getPageNumberingFontSize() != page2.getPageNumberingFontSize())
 		return false;
 
-	for (uint8_t i=0; i<WPX_NUM_HEADER_FOOTER_TYPES; i++) {
+	for (uint8_t i=0; i<WPX_NUM_HEADER_FOOTER_TYPES; i++)
+	{
 		if (page1.getHeaderFooterSuppression(i) != page2.getHeaderFooterSuppression(i))
 			return false;
 	}
@@ -253,28 +260,29 @@ bool operator==(const WPXPageSpan &page1, const WPXPageSpan &page2)
 	// NOTE: yes this is O(n^2): so what? n=4 at most
 	const std::vector<WPXHeaderFooter> headerFooterList1 = page1.getHeaderFooterList();
 	const std::vector<WPXHeaderFooter> headerFooterList2 = page2.getHeaderFooterList();
-	std::vector<WPXHeaderFooter>::const_iterator iter1;		
-	std::vector<WPXHeaderFooter>::const_iterator iter2;		
+	std::vector<WPXHeaderFooter>::const_iterator iter1;
+	std::vector<WPXHeaderFooter>::const_iterator iter2;
 
 	for (iter1 = headerFooterList1.begin(); iter1 != headerFooterList1.end(); iter1++)
 	{
 		if (std::find(headerFooterList2.begin(), headerFooterList2.end(), (*iter1)) == headerFooterList2.end())
 			return false;
 	}
-	
+
 	// If we came here, we know that every header/footer that is found in the first page span is in the second too.
 	// But this is not enought for us to know whether the page spans are equal. Now we have to check in addition
 	// whether every header/footer that is in the second one is in the first too. If someone wants to optimize this,
 	// (s)he is most welcome :-)
-	
+
 	for (iter2 = headerFooterList2.begin(); iter2 != headerFooterList2.end(); iter2++)
 	{
 		if (std::find(headerFooterList1.begin(), headerFooterList1.end(), (*iter2)) == headerFooterList1.end())
 			return false;
 	}
 
-	
+
 	WPD_DEBUG_MSG(("WordPerfect: WPXPageSpan == comparison finished, found no differences\n"));
 
 	return true;
 }
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
